package com.zehong.system.mapper;

import java.util.List;
import com.zehong.system.domain.ProductStandardInspection;
import org.apache.ibatis.annotations.Param;

/**
 * 产品主体标检单Mapper接口
 *
 * @author zehong
 * @date 2026-01-17
 */
public interface ProductStandardInspectionMapper
{
    /**
     * 查询产品主体标检单
     *
     * @param productStandardInspectionId 产品主体标检单ID
     * @return 产品主体标检单
     */
    public ProductStandardInspection selectProductStandardInspectionById(Long productStandardInspectionId);

    public ProductStandardInspection selectByProductStandardInspectionNumber(String productStandardInspectionNumber);

    public ProductStandardInspection selectByNumber(String number);


    /**
     * 查询产品主体标检单列表
     *
     * @param productStandardInspection 产品主体标检单
     * @return 产品主体标检单集合
     */
    public List<ProductStandardInspection> selectProductStandardInspectionList(ProductStandardInspection productStandardInspection);

    public List<ProductStandardInspection> exportExcel(ProductStandardInspection productStandardInspection);

    public List<ProductStandardInspection> selectDuringStandardInspection();
    /**
     * 新增产品主体标检单
     *
     * @param productStandardInspection 产品主体标检单
     * @return 结果
     */
    public int insertProductStandardInspection(ProductStandardInspection productStandardInspection);

    public int batchInsert(@Param("list") List<ProductStandardInspection> list);

    /**
     * 修改产品主体标检单
     *
     * @param productStandardInspection 产品主体标检单
     * @return 结果
     */
    public int updateProductStandardInspection(ProductStandardInspection productStandardInspection);

    /**
     * 删除产品主体标检单
     *
     * @param productStandardInspectionId 产品主体标检单ID
     * @return 结果
     */
    public int deleteProductStandardInspectionById(Long productStandardInspectionId);

    /**
     * 批量删除产品主体标检单
     *
     * @param productStandardInspectionIds 需要删除的数据ID
     * @return 结果
     */
    public int deleteProductStandardInspectionByIds(Long[] productStandardInspectionIds);
}
